### loading packages

require(FactoMineR)
require(lattice)
require(MASS)
require(car)
require(effects)
require(mgcv)
require(dplyr)
require(multcomp)
require(lsmeans)
require(readr)
require(corrplot)
require(emmeans)
require(lme4)


################################## STUDY 1 ######################################################

## laoding dataset-----
study1<-read.table("/Users/zegni/Google Drive/1.Files_manuscripts/Ros et al./stats/Albert15062018/figshare/study1.csv",header=TRUE,sep=",")
sapply(study1,class)

study1$patch_ID <- as.factor(study1$patch_ID)

xtabs(~ treatment+species, study1)

### model for body condition analyses-----
### --------------------------------- ###

study1$body.condition <- study1$girth / study1$total_length 

hist(study1$body.condition)
shapiro.test(study1$body.condition)## normality looks good with shapiro

bwplot(body.condition~ treatment | species, data=study1)

model.body.condition = lmer(body.condition ~ treatment * species+ 
                           (1|patch_ID), na.action=na.exclude, data=study1)


Anova(model.body.condition)

### Checking Model Assumptions ###
qqPlot(resid(model.body.condition)) 
shapiro.test(resid(model.body.condition))## all good

plot(resid(model.body.condition))# looks good
qqPlot(resid(model.body.condition))# looks good
par(mfrow=c(2,2)); plot(model.body.condition); par(mfrow=c(1,1))# looks good


# posthoc
emmeans(model.body.condition, pairwise~treatment|species, adjust="tukey")## i cannot reproduce your results Albert :(


## White blood cells----

### linear model for leukocyte analyses###
### --------------------------------- ###

hist(study1$white_cells_prop)

shapiro.test(logit(study1$white_cells_prop))
hist(logit(study1$white_cells_prop))

qqp(logit(study1$white_cells_prop), "norm")
bwplot(logit(study1$white_cells_prop)~ treatment|species , data=study1)


model.W=lmer(logit(white_cells_prop) ~ treatment * species+ (1|patch_ID), 
             na.action=na.omit, 
             data=study1)

Anova(model.W)

### Checking Model Assumptions ###
qqPlot(resid(model.W)) 
shapiro.test(resid(model.W))## doesn't look good!!

plot(resid(model.W))
qqPlot(resid(model.W))
par(mfrow=c(2,2)); plot(model.W); par(mfrow=c(1,1))


# posthoc
summary(glht(model.W, linfct=lsm(pairwise ~ species)))



### linear model for granulocyte_prop analyses###
### --------------------------------- ###

hist(study1$granulocyte_prop)

shapiro.test(asin(sqrt(study1$granulocyte_prop)))
hist(asin(sqrt(study1$granulocyte_prop)))

qqp(asin(sqrt(study1$granulocyte_prop)), "norm")
bwplot(asin(sqrt(study1$granulocyte_prop))~ treatment|species , data=study1)


model.G=lmer(asin(sqrt(granulocyte_prop)) ~ treatment * species+ (1|patch_ID), 
             na.action=na.omit, 
             data=study1)

Anova(model.G)

### Checking Model Assumptions ###
qqPlot(resid(model.G)) 
shapiro.test(resid(model.G))

plot(resid(model.G))
qqPlot(resid(model.G))
par(mfrow=c(2,2)); plot(model.G); par(mfrow=c(1,1))


# posthoc
summary(glht(model.G, linfct=lsm(pairwise ~ species)))




### linear model for lymphocyte_prop analyses###
### --------------------------------- ###

hist(study1$lymphocyte_prop)

shapiro.test(logit(study1$lymphocyte_prop))
hist(logit(study1$lymphocyte_prop))

qqp(logit(study1$lymphocyte_prop), "norm")
bwplot(logit(study1$lymphocyte_prop)~ treatment|species , data=study1)


model.L=lmer(logit(lymphocyte_prop) ~ treatment * species+ (1|patch_ID), 
             na.action=na.omit, 
             data=study1)

Anova(model.L)

### Checking Model Assumptions ###
qqPlot(resid(model.L)) 
shapiro.test(resid(model.L))

plot(resid(model.L))
qqPlot(resid(model.L))
par(mfrow=c(2,2)); plot(model.L); par(mfrow=c(1,1))


# posthoc
summary(glht(model.L, linfct=lsm(pairwise ~ species)))


### linear model for phagocytosis analyses----
### --------------------------------- ###

hist(log(study1$phagocytosis+0.875))## a constant 0.875, to have minmum value = 1
shapiro.test(log(study1$phagocytosis+0.875))## normality looks good with shapiro

bwplot(log(study1$phagocytosis+0.875)~ treatment | species, data=study1)

model.phago = lmer(log(phagocytosis+0.875) ~ treatment * species+ 
                     (1|patch_ID), na.action=na.exclude, 
                           data=subset(study1, species!="P. ambonensis"))


Anova(model.phago)

### Checking Model Assumptions ###
qqPlot(resid(model.phago)) 
shapiro.test(resid(model.phago))## all good

plot(resid(model.phago))# looks good
qqPlot(resid(model.phago))# looks good
par(mfrow=c(2,2)); plot(model.phago); par(mfrow=c(1,1))# looks good


# posthoc
summary(glht(model.phago, linfct=lsm(pairwise ~ treatment|species)))



### linear model for lytic_activity analyses-----
### --------------------------------- ###

hist(log(study1$lytic_activity+1))
shapiro.test(log(study1$lytic_activity+1))## normality looks good with shapiro

bwplot(log(study1$lytic_activity+1)~ treatment | species, data=study1)

model.lytic = lmer(log(lytic_activity+1) ~ treatment * species+ 
                   (1|patch_ID), na.action=na.exclude, 
                  data=study1)


Anova(model.lytic)

### Checking Model Assumptions ###
qqPlot(resid(model.lytic)) 
shapiro.test(resid(model.lytic))## all good

plot(resid(model.lytic))# looks good
qqPlot(resid(model.lytic))# looks good
par(mfrow=c(2,2)); plot(model.lytic); par(mfrow=c(1,1))# looks good


# posthoc
summary(glht(model.lytic, linfct=lsm(pairwise ~ treatment|species)))




### linear model for cortisol analyses-----
### --------------------------------- ###

hist(study1$cortisol)
shapiro.test(study1$cortisol)
bwplot((study1$cortisol)~ treatment | species, data=study1)


require(goft)
gamma_test(study1$cortisol)## we have gamma distribution


study1.cortisol <- c("patch_ID", "treatment", "species", "cortisol")
study1.cortisol <- study1[study1.cortisol]
study1.cortisol <-subset(study1.cortisol, cortisol!="NA")## to get rid of NAs
study1.cortisol <- subset(study1.cortisol, species!="A. polyacanthus")## no data from this sepcies in the removal treatment!! 


require(lmerTest)
model.cortisol = glmer(cortisol ~ treatment * species+(1|patch_ID), family=Gamma,
                        data=study1.cortisol)

Anova(model.cortisol)
summary(model.cortisol)

### Checking Model Assumptions ###
qqPlot(resid(model.cortisol)) 
shapiro.test(resid(model.cortisol))

plot(resid(model.cortisol))
qqPlot(resid(model.cortisol))
par(mfrow=c(2,2)); plot(model.cortisol); par(mfrow=c(1,1))


# posthoc
summary(glht(model.cortisol, linfct=lsm(pairwise ~ treatment|species)))



### linear model for testosterone analyses----
### --------------------------------- ###

study1.test <- subset(study1, species=="D. perspicillat")
hist(study1.test$testosterone)
hist(log(study1.test$testosterone+1))
shapiro.test(study1.test$testosterone)
shapiro.test(log(study1.test$testosterone+1))



bwplot(log(study1.test$testosterone+1)~ treatment , data=study1.test)

model.test = lmer(log(testosterone+1) ~ treatment+ 
                  (1|patch_ID), na.action=na.exclude, 
                  data=study1.test)


Anova(model.test)

### Checking Model Assumptions ###
qqPlot(resid(model.test)) 
shapiro.test(resid(model.test))

plot(resid(model.test))
qqPlot(resid(model.test))
par(mfrow=c(2,2)); plot(model.test); par(mfrow=c(1,1))


### linear model for antibody analyses----
### --------------------------------- ###

hist(subset(study1, species=="D. perspicillat")$SRBC)

bwplot(SRBC~ treatment , data=subset(study1, species=="D. perspicillat"))


model.S=glmer(SRBC ~ treatment+(1|patch_ID), 
              na.action=na.omit, family=poisson,
              data=subset(study1, species=="D. perspicillat"))

Anova(model.S)

### Checking Model Assumptions ###
qqPlot(resid(model.S)) 
shapiro.test(resid(model.S))## doesn't look good!!

plot(resid(model.S))
qqPlot(resid(model.S))
par(mfrow=c(2,2)); plot(model.S); par(mfrow=c(1,1))



### Correlations between all the physiological measurements ------
### ------------------------------------------------------- ###
##### Correlations within each treatment
### fish from control patches

study1$interaction <- study1$species:study1$treatment
head(study1)

levels(study1$interaction)

dat1 <- subset(study1, interaction=="A. curacao:control")
dat2 <- subset(study1, interaction=="A. curacao:removal")

dat3 <- subset(study1, interaction=="A. polyacanthus:control")
dat4 <- subset(study1, interaction=="A. polyacanthus:removal")

dat5 <- subset(study1, interaction=="D. perspicillat:control")
dat6 <- subset(study1, interaction=="D. perspicillat:removal")

dat7 <- subset(study1, interaction=="P. ambonensis:control")
dat8 <- subset(study1, interaction=="P. ambonensis:removal")


## A. curacao----


dat1 <- dat1[,c(22,21,19,20,11,12,8)]
head(dat1)

cor1 <- cor(dat1, use="pairwise.complete.obs", method="pearson")
head(cor1)


corrplot(cor1,  method="circle", tl.pos="lt",        
         tl.col="black", tl.cex=0.6, tl.srt=45, 
         addCoef.col="black", number.cex=0.7,
         p.mat = 1-abs(cor1), sig.level=0.3, 
         insig = "blank", type="upper") 






dat2 <- dat2[,c(22,21,19,20,11,12)]
head(dat2)

cor1 <- (cor(dat2, use="pairwise.complete.obs", method="spearman"))
head(cor1)


corrplot(cor1,  method="circle", tl.pos="lt",        
         tl.col="black", tl.cex=0.6, tl.srt=45, 
         addCoef.col="black", number.cex=0.7,
         p.mat = 1-abs(cor1), sig.level=0.3, type="upper",
         insig = "blank") 



## A. polyacanthus----
dat3 <- dat3[,c(22,21,19,20,11,12)]
head(dat3)

cor1 <- (cor(dat3, use="pairwise.complete.obs", method="spearman"))
head(cor1)


corrplot(cor1,  method="circle", tl.pos="lt",        
         tl.col="black", tl.cex=0.6, tl.srt=45, 
         addCoef.col="black", number.cex=0.7,
         p.mat = 1-abs(cor1), sig.level=0.3, type="upper",insig = "blank") 






dat4 <- dat4[,c(22,21,19,20,11,12)]
head(dat4)

cor1 <- (cor(dat4, use="pairwise.complete.obs", method="spearman"))
head(cor1)


corrplot(cor1,  method="circle", tl.pos="lt",        
         tl.col="black", tl.cex=0.6, tl.srt=45, 
         addCoef.col="black", number.cex=0.7,
         p.mat = 1-abs(cor1), sig.level=0.3, type="upper",insig = "blank") 


## D. perspicillat----
dat5 <- dat5[,c(22,21,19,20,11,12,18,8,9)]
head(dat5)

cor1 <- (cor(dat5, use="pairwise.complete.obs", method="spearman"))
head(cor1)


corrplot(cor1,  method="circle", tl.pos="lt",        
         tl.col="black", tl.cex=0.6, tl.srt=45, 
         addCoef.col="black", number.cex=0.7,
         p.mat = 1-abs(cor1), sig.level=0.3, type="upper",insig = "blank") 






dat6 <- dat6[,c(22,21,19,20,11,12,18,8,9)]
head(dat6)

cor1 <- (cor(dat6, use="pairwise.complete.obs", method="spearman"))
head(cor1)


corrplot(cor1,  method="circle", tl.pos="lt",        
         tl.col="black", tl.cex=0.6, tl.srt=45, 
         addCoef.col="black", number.cex=0.7,
         p.mat = 1-abs(cor1), sig.level=0.3, type="upper",insig = "blank") 


## P. ambonensis----
dat7 <- dat7[,c(22,21,19,20,12,8)]
head(dat7)

cor1 <- (cor(dat7, use="pairwise.complete.obs", method="spearman"))
head(cor1)


corrplot(cor1,  method="circle", tl.pos="lt",        
         tl.col="black", tl.cex=0.6, tl.srt=45, 
         addCoef.col="black", number.cex=0.7,
         p.mat = 1-abs(cor1), sig.level=0.3, type="upper",insig = "blank") 






dat8 <- dat8[,c(22,12,8)]
head(dat8)

cor1 <- (cor(dat8, use="pairwise.complete.obs", method="spearman"))
head(cor1)


corrplot(cor1,  method="circle", tl.pos="lt",        
         tl.col="black", tl.cex=0.6, tl.srt=45, 
         addCoef.col="black", number.cex=0.7,
         p.mat = 1-abs(cor1), sig.level=0.3,type="upper", insig = "blank") 











